<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              www.lyo.one
 * @since             1.0.0
 * @package           Nilly
 *
 * @wordpress-plugin
 * Plugin Name:       Nilly
 * Plugin URI:        www.nilly.io
 * Description:       This plugin adds the lightweight nilly code directly to your footer. For simple & fast real-time website analytics that belong to you.
 * Version:           1.3.1
 * Author:            Lyo GmbH
 * Author URI:        www.lyo.one
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       nilly
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'NILLY_VERSION', '1.3.1' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-nilly-activator.php
 */
function activate_nilly() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-nilly-activator.php';
	Nilly_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-nilly-deactivator.php
 */
function deactivate_nilly() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-nilly-deactivator.php';
	Nilly_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_nilly' );
register_deactivation_hook( __FILE__, 'deactivate_nilly' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-nilly.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_nilly() {

	$plugin = new Nilly();
	$plugin->run();

}
run_nilly();
